@@ -20,13 +20,11 @@ format_valuef <- function(digits) {
 #'  standard errors for the estimates, log-likelihood, information criteria values,
 #'  modulus of the roots of the characteristic AR polynomias for each regime, and
 #'  several unconditional moments.
-#'  Supported for models that include data only.
 #' @export
 
 print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
   gsmar <- x
   stopifnot(digits >= 0 & digits %% 1 == 0)
-  if(summary_print) check_data(gsmar)
 
   # Help functions
   format_value <- format_valuef(digits)
@@ -53,7 +51,7 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
     params <- change_parametrization(p=p, M=M, params=params, model=model, restricted=restricted,
                                      constraints=constraints, change_to="intercept")
   }
-  params <- removeAllConstraints(p=p, M=M, params=params, model=model, restricted=restricted,
+  params <- remove_all_constraints(p=p, M=M, params=params, model=model, restricted=restricted,
                                  constraints=constraints)
   all_phi0 <- pick_phi0(p=p, M=M, params=params, model=model, restricted=FALSE, constraints=NULL)
   pars <- pick_pars(p=p, M=M, params=params, model=model, restricted=FALSE, constraints=NULL)
@@ -62,8 +60,8 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
 
   if(summary_print) {
     all_ar_roots <- get_ar_roots(gsmar)
-    std_errors <- removeAllConstraints(p=p, M=M, params=gsmar$std_errors, model=model, restricted=restricted,
-                                       constraints=constraints) # These errors are valid only if there is no multiplications or summations
+    std_errors <- remove_all_constraints(p=p, M=M, params=gsmar$std_errors, model=model, restricted=restricted,
+                                         constraints=constraints) # These errors are valid only if there is no multiplications or summations
     pars_err <- pick_pars(p=p, M=M, params=std_errors, model=model, restricted=FALSE, constraints=NULL)
     alphas_err <- pick_alphas(p=p, M=M, params=std_errors, model=model, restricted=FALSE, constraints=NULL)
     alphas_err[sum(M)] <- NA
@@ -118,7 +116,7 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
     cat(paste("Regime", m))
     if(model == "G-StMAR") cat(paste0(" (", regime_type, " type)"))
 
-    if(summary_print) cat(paste("\nModulus of poly roots:", paste0(format_value(all_ar_roots[[m]]), collapse=", ")))
+    if(summary_print) cat(paste("\nModuli of AR poly roots:", paste0(format_value(all_ar_roots[[m]]), collapse=", ")))
 
     cat(paste("\nMix weight:", format_value(alphas[m])))
     print_err(alphas_err[m])
@@ -187,14 +185,6 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
 #' @param x object of class 'gsmarsum' generated by \code{summary.gsmar}.
 #' @param ... currently not in use.
 #' @param digits the number of digits to be printed
-#' @examples
-#' \donttest{
-#' # GMAR model
-#' fit12 <- fitGSMAR(simudata, 1, 2, ncalls=4)
-#' gsmarsum12 <- summary(fit12)
-#' gsmarsum12
-#' print(gsmarsum12, digits=4)
-#' }
 #' @export
 
 print.gsmarsum <- function(x, ..., digits) {
@@ -211,15 +201,6 @@ print.gsmarsum <- function(x, ..., digits) {
 #'
 #' @inheritParams print.gsmarsum
 #' @param x object of class \code{'gsmarpred'} generated by \code{predict.gsmar}.
-#' @examples
-#'  \donttest{
-#'  # GMAR-model
-#'  params12 <-  c(0.18, 0.93, 0.01, 0.86, 0.68, 0.02, 0.88)
-#'  gmar12 <- GSMAR(simudata, 1, 2, params12)
-#'  pred <- predict(gmar12, n_ahead=10, plotRes=FALSE)
-#'  pred
-#'  print(pred, digits=3)
-#'  }
 #' @export
 
 print.gsmarpred <- function(x, ..., digits=2) {
@@ -265,8 +246,8 @@ print.gsmarpred <- function(x, ..., digits=2) {
 }
 
 
-#' @describeIn quantileResidualTests Print method for class 'qrtest' objects
-#' @param x object of class \code{'qrtest'} created with the function \code{quantileResidualTests}.
+#' @describeIn quantile_residual_tests Print method for class 'qrtest' objects
+#' @param x object of class \code{'qrtest'} created with the function \code{quantile_residual_tests}.
 #' @param ... graphical parameters passed to \code{segments} in \code{plot.qrtest}.
 #'  Currectly not used in \code{print.qrtest}
 #' @param digits the number of digits to be print
